@@ -6,7 +6,7 @@ qbit::Exceptions - qbit exceptions
 =cut
 
 package qbit::Exceptions;
-$qbit::Exceptions::VERSION = '2.2';
+$qbit::Exceptions::VERSION = '2.3';
 =head1 Synopsis
 
 Usage:
@@ -176,8 +176,18 @@ sub throw($) {
     die $exception;
 }
 
+sub die_handler {
+    die @_ unless defined($^S);    # Perl parser errors
+
+    my ($exception) = @_;
+
+    $exception = Exception::SysDie->new($exception) unless ref($exception);
+
+    die $exception;
+}
+
 package Exception;
-$Exception::VERSION = '2.2';
+$Exception::VERSION = '2.3';
 use strict;
 use warnings;
 use overload '""' => sub {shift->as_string()};
@@ -196,7 +206,7 @@ sub new {
     while (1) {
 
         package DB;
-$DB::VERSION = '2.2';
+$DB::VERSION = '2.3';
         my ($package, $filename, $line, $subroutine, $hasargs, $wantarray, $evaltext, $is_require, $hints, $bitmask) =
           caller($i);
 
@@ -265,7 +275,7 @@ sub as_string {
 }
 
 package Exception::SysDie;
-$Exception::SysDie::VERSION = '2.2';
+$Exception::SysDie::VERSION = '2.3';
 use base qw(Exception);
 
 use strict;
@@ -280,11 +290,11 @@ sub new {
 }
 
 package Exception::BadArguments;
-$Exception::BadArguments::VERSION = '2.2';
+$Exception::BadArguments::VERSION = '2.3';
 use base qw(Exception);
 
 package Exception::Denied;
-$Exception::Denied::VERSION = '2.2';
+$Exception::Denied::VERSION = '2.3';
 use base qw(Exception);
 
 1;
